CountyService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBoundaryForCounty(
{required String county, required String stateCode}) → Future< List< LatLng> > - Returns the bounday coordinates for a specific county name and state code
-
getCountyAndStateCodeFromAddress(
String address) → Future< ({String? county, String? stateCode})> - Returns both county name and state code (e.g. 'CA') for a given address
-
getCountyFromAddress(
String address) → Future< String?> - Returns the county name for a given address
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited